@@ -19,7 +19,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-extern int root_override;
+#ifndef __COMMANDLINE_H_
+#define __COMMANDLINE_H_
 
-extern int
-parse_commandline (int argc, char **argv);
+extern int root_override;
+extern gchar *load_filename, *load_projectname;
+
+int parse_commandline(int argc, char **argv);
+
+#endif							/* __COMMANDLINE_H_ */
