@@ -28,7 +28,6 @@
 #include <glib.h>
 #include <gtk/gtkwidget.h>
 
-void configure (GtkWidget * widget, gpointer data);
-
-#endif	/* __CONFIGURE_H_ */
+void configure_cb(GtkWidget * widget, gpointer data);
 
+#endif							/* __CONFIGURE_H_ */
