@@ -22,9 +22,18 @@
 
 #include <gtk/gtk.h>
 
-extern GtkWidget *combo_with_popdown( gchar *setstring , GList *which_list, gint editable);
-extern GtkWidget *bf_stock_button (const gchar *Text, GtkSignalFunc func, gpointer func_data);
-extern GtkWidget *bf_stock_ok_button (GtkSignalFunc func, gpointer func_data);
-extern GtkWidget *bf_stock_cancel_button (GtkSignalFunc func, gpointer func_data);
+/* GtkWindowPosition can be 
+GTK_WIN_POS_NONE
+GTK_WIN_POS_CENTER
+GTK_WIN_POS_MOUSE */
 
+void setup_toggle_item(GtkItemFactory * ifactory, gchar * path, gint state);
+void string_apply(gchar ** config_var, GtkWidget * entry);
+GtkWidget *combo_with_popdown(gchar * setstring, GList * which_list, gint editable);
+GtkWidget *entry_with_text(gchar * setstring, gint max_lenght);
+GtkWidget *window_with_title(gchar * title, GtkWindowPosition position, GtkWindowType type, gint borderwidth);
+GtkWidget *apply_font_style(GtkWidget * this_widget, gchar * fontstring);
+GtkWidget *bf_stock_button(const gchar * Text, GtkSignalFunc func, gpointer func_data);
+GtkWidget *bf_stock_ok_button(GtkSignalFunc func, gpointer func_data);
+GtkWidget *bf_stock_cancel_button(GtkSignalFunc func, gpointer func_data);
 #endif
