@@ -26,15 +26,14 @@
 #include <glib.h>
 #include <gtk/gtkwidget.h>
 
-void copy_callback(GtkWidget * w, gpointer data);
-void paste_callback(GtkWidget * w, gpointer data);
-void cut_callback(GtkWidget * w, gpointer data);
-void sel_all_callback(GtkWidget * w, gpointer data);
+void copy_cb(GtkWidget * w, gpointer data);
+void paste_cb(GtkWidget * w, gpointer data);
+void cut_cb(GtkWidget * w, gpointer data);
+void sel_all_cb(GtkWidget * w, gpointer data);
 
-void search_search_cmd_callback(GtkWidget * w, gpointer data);
-void search_replace_cmd_callback(GtkWidget * w, gpointer data);
-void search_again_cmd_callback(GtkWidget * w, gpointer data);
+void search_search_cmd_cb(GtkWidget * w, gpointer data);
+void search_replace_cmd_cb(GtkWidget * w, gpointer data);
+void search_again_cmd_cb(GtkWidget * w, gpointer data);
 void snr_init();
 
-#endif	/* __SNR_H_ */
-
+#endif							/* __SNR_H_ */
